@@ -1,7 +1,7 @@
 #!/bin/sh
 
 set_project "tbox"
-set_version "1.7.5" "%Y%m%d" "1"
+set_version "1.7.7" "%Y%m%d" "1"
 
 # set warning all as error
 set_warnings "all" "error"
@@ -37,6 +37,8 @@ if is_plat "mingw" "msys" "cygwin"; then
     add_syslinks "ws2_32" "pthread" "m"
 elif is_plat "haiku"; then
     add_syslinks "pthread" "network" "m" "c"
+elif is_plat "bsd" "solaris"; then
+    add_syslinks "pthread" "m"
 else
     add_syslinks "pthread" "dl" "m" "c"
 fi
